#' GetMissingnessSummaryPlot
#'
#' Create plot with overview of missing data.
#'
#' @param inputData Pre-processed input data. Required.
#' @param columnNames Names of columns in \code{inputData} selected for missingness plot. Optional.
#'   Default = \code{c("Transmission", "Migr", "Gender", "Age", "CD4_num")}
#' @param labels Labels to be displayed instead of strings in \code{columnNames}. Optional.
#'   Default = \code{c("Transm.", "Migrant", "Gender", "Age", "CD4")}
#'
#' @return plot object
#'
#' @examples
#' \dontrun{
#' GetMissingnessSummaryPlot()
#' }
#'
#' @export
GetMissingnessSummaryPlot <- function(
  inputData,
  columnNames = c("Transmission", "Migr", "Gender", "Age", "CD4_num"),
  labels = c("Transm.", "Migrant", "Gender", "Age", "CD4"))
{
  stopifnot(!missing(inputData))

  columnNames <- columnNames[columnNames %in% colnames(inputData)]

  if (length(columnNames) > 0) {
    aggrPlot <- GetMissingness(inputData[, ..columnNames])

    PlotMissingness(aggrPlot,
                    combined = FALSE,
                    numbers = TRUE,
                    prop = TRUE,
                    sortVars = TRUE,
                    varheight = FALSE,
                    digits = 2,
                    labels = labels,
                    cex.axis = .9,
                    gap = 1,
                    ylabs = c("Relative frequency of missing data",
                              "Missing data patterns"))

  } else {
    aggrPlot <- NULL
  }

  return(aggrPlot)
}
